==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/floppy/demo_dialogs_fr.lua <==

dialogId("dlg-x-poster1", "font_orange", "THE GREATEST EARTHQUAKE SINCE 1990")
dialogStr("LE PLUS GRAND TREMBLEMENT DE TERRE DEPUIS 1990")


dialogId("dlg-x-poster2", "font_orange", "when Dragon's Lair was issued, Rules for beginners, version 1.0.")
dialogStr("date de la publication de Dragon's Lair, Règles pour les débutants, version 1.0.")


dialogId("dlg-x-poster4", "font_orange", "The world of role-playing games will soon change forever.")
dialogStr("Le monde du jeu de rôle sera transformé à jamais.")


dialogId("dlg-x-poster5", "font_orange", "Dragon's Lair Plus is not only a new version.")
dialogStr("Dragon's Lair Plus n'est pas une simple nouvelle version.")


dialogId("dlg-x-poster6", "font_orange", "It's a new game.")
dialogStr("C'est un nouveau jeu.")


dialogId("dlg-x-poster7", "font_orange", "Plenty of new possibilities. New occupations. New system of character creation, where, instead of your lives, your skills grow. New elegant mechanism of playing.")
dialogStr("De nombreuses nouvelles possibilités. Nouvelles carrières. Nouveau système de création des personnages, avec augmentations des compétences. Nouveau mécanisme de jeu intuitif.")


dialogId("dlg-x-poster8", "font_orange", "A game for 21. century.")
dialogStr("Un jeu pour le 21 siècle.")


dialogId("dlg-x-poster9", "font_orange", "GAMES HAVE CHANGED")
dialogStr("LES JEUX DOIVENT CHANGER")


dialogId("dlg-x-poster10", "font_poster", "This is what we get from the computer after inserting the waterproof diskette that was found during our investigation of secret criminal organisation.")
dialogStr("C'est ce que nous avons obtenu en insérant la disquette étanche que nous avons trouvée lors de nos investigations à propos d'une organisation secrète et criminelle.")


dialogId("dlg-x-poster11", "font_poster", "We are shocked. Do not let journalists know it.")
dialogStr("Nous sommes abasourdis. Ne laissez pas les journalistes en prendre connaissance.")


dialogId("dlg-x-poster12", "font_poster", "You must prevent the panic.")
dialogStr("Nous devons éviter la panique.")


dialogId("dlg-x-poster13", "font_poster", "And subscribe two copies for us.")
dialogStr("Et commander deux copie pour nous.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/floppy/demo_dialogs_fr.lua <==

dialogId("dlg-x-poster1", "font_orange", "THE GREATEST EARTHQUAKE SINCE 1990")
dialogStr("LE PLUS GRAND TREMBLEMENT DE TERRE DEPUIS 1990")


dialogId("dlg-x-poster2", "font_orange", "when Dragon's Lair was issued, Rules for beginners, version 1.0.")
dialogStr("date de la publication de Dragon's Lair, Règles pour les débutants, version 1.0.")


dialogId("dlg-x-poster4", "font_orange", "The world of role-playing games will soon change forever.")
dialogStr("Le monde des jeux de rôle sera transformé à jamais.")


dialogId("dlg-x-poster5", "font_orange", "Dragon's Lair Plus is not only a new version.")
dialogStr("Dragon's Lair Plus n'est pas une simple nouvelle version.")


dialogId("dlg-x-poster6", "font_orange", "It's a new game.")
dialogStr("C'est un nouveau jeu.")


dialogId("dlg-x-poster7", "font_orange", "Plenty of new possibilities. New occupations. New system of character creation, where, instead of your lives, your skills grow. New elegant mechanism of playing.")
dialogStr("De nombreuses nouvelles possibilités. Nouvelles carrières. Nouveau système de création des personnages, avec augmentations des compétences. Nouveau mécanisme de jeu intuitif.")


dialogId("dlg-x-poster8", "font_orange", "A game for 21. century.")
dialogStr("Un jeu pour le 21ème siècle.")


dialogId("dlg-x-poster9", "font_orange", "GAMES HAVE CHANGED")
dialogStr("LES JEUX ONT CHANGÉ")


dialogId("dlg-x-poster10", "font_poster", "This is what we get from the computer after inserting the waterproof diskette that was found during our investigation of secret criminal organisation.")
dialogStr("C'est ce que nous avons obtenu en insérant la disquette étanche que nous avons trouvée lors de notre enquête sur une organisation secrète et criminelle.")


dialogId("dlg-x-poster11", "font_poster", "We are shocked. Do not let journalists know it.")
dialogStr("Nous sommes abasourdis. Ne laissez pas les journalistes en prendre connaissance.")


dialogId("dlg-x-poster12", "font_poster", "You must prevent the panic.")
dialogStr("Nous devons éviter la panique.")


dialogId("dlg-x-poster13", "font_poster", "And subscribe two copies for us.")
dialogStr("Et commander deux copies pour nous.")
